%define daemon_user monitor
%if 0%{?suse_version}
%define htmlroot /srv/www/htdocs
%define httpconfdir apache2/conf.d
%define daemon_group www
%define apache_group wwwrun
%else
%define htmlroot /var/www/html
%define httpconfdir httpd/conf.d
%define daemon_group apache
%define apache_group apache
Requires: php-cli
%endif
Name: op5-synergy-processor
Version: 7.0.3
Release: op5.1
License: op5 Software License
Packager: build@op5
Vendor: op5 AB
BuildRoot: %{_tmppath}/%{name}-%{version}
Summary: Business service handler processor
Group: op5/Monitor
Prefix: /opt/synergy
BuildArch: noarch
Requires: lua, monitor-livestatus, monitor-nacoma, monitor-ninja
Requires: op5-synergy-luapack >= 1.1.1-beta3
Requires: op5-monitor-supported-database
Requires: python
Requires: merlin
BuildRequires: lua
BuildRequires: op5-monitor-supported-database
BuildRequires: merlin
BuildRequires: op5-synergy-luapack >= 1.1.1-beta3
BuildRequires: monitor-livestatus
Source: %name-%version.tar.gz
Source1: init.patch
Obsoletes: op5-synergy <= 1.1.0
Provides: op5-synergy

%description
Handles business services according to user defined rules.

%package test
Summary: Test files for op5-synergy-processor
Group: op5/Monitor
Requires: op5-synergy-processor = %version
Requires: portal
Requires: monitor-ninja
Requires: monitor-ninja-test
Requires: op5license-generator
Requires: monitor-livestatus
Requires: rubygem20-op5cucumber
# our tests won't run without this particular supported-database
Requires: op5-mysql

%description test
Misc test files for op5-synergy-processor

%prep
rm -rf %buildroot
%setup -q
%if 0%{?suse_version}
sed -i '1s#/bin/lua.*#/bin/lua5.1#' bin/actions bin/synergy
find . -name '*.lua' -exec sed -i '1s#/bin/lua.*#/bin/lua5.1#' {} \;
patch -p1 < %_sourcedir/init.patch
%endif

%install
make INSTALL_TOP=%buildroot%prefix install
mkdir -p -m 744 %buildroot/opt/monitor/etc/synergy
mkdir -p -m 777 %buildroot%prefix/var/spool
mkdir -p -m 777 %buildroot%prefix/var/queue
mkdir -p %buildroot/etc/op5kad/conf.d
mkdir -p %buildroot/opt/monitor/op5/ninja/modules
cp -r synergy %buildroot/opt/monitor/op5/ninja/modules
mkdir -p -m 744 %buildroot/opt/monitor/op5/nacoma/hooks/save
cp -r external/hook/* %buildroot/opt/monitor/op5/nacoma/hooks/save
cp -r external/opt/* %buildroot/opt
cp -r op5kad/synergy.kad %buildroot/etc/op5kad/conf.d/
mkdir -p -m 755 %buildroot%prefix/etc/rules/repo
mkdir -p -m 755 %buildroot%prefix/etc/rules/custom/repo
mkdir -p -m 755 %buildroot%prefix/etc/bps
mkdir -p -m 755 %buildroot/etc/init.d
cp -r etc/init.d/synergy %buildroot/etc/init.d/synergy
cp -r etc/op5-backup %buildroot/etc/
mkdir -p -m 755 %buildroot%prefix/sql
cp -a sql/* %buildroot%prefix/sql/
cp Makefile %buildroot%prefix/
cp -a test %buildroot%prefix/test
mkdir -p %buildroot%prefix/test/var
cp -a features %buildroot%prefix/features

%if 0%{?sles_version}
%{py_compile %buildroot/opt/monitor/op5/nacoma/hooks/save}
%{py_compile -O %buildroot/opt/monitor/op5/nacoma/hooks/save}
%endif

%post
# Adjust rules and their file names
if ! python %prefix/scripts/fix-rules.py; then
	echo "Failed to fix rules."
	echo "Please rerun %prefix/scripts/fix-rules.py manually and"
	echo "contact support@op5.com if that doesn't solve the issue."
	sleep 5
fi

# Verify that mysql-server is installed and running before executing sql scripts
# TODO: Is it really a good idea to hide mysql errors?
$(mysql -Be "quit" 2>/dev/null)
if [ $? -eq 0 ]; then
	sh %prefix/sql/mysql/install-mysql.sh
else
  echo "WARNING: mysql-server is not installed or not running."
  echo "If Oracle database is to be used this is ok."
  echo "If MySQL database is to be used you need to maually run database"
  echo "install/upgrade procedures to complete the setup of %name"
fi

if ! grep -q '^cfg_dir=/opt/monitor/etc/synergy$' /opt/monitor/etc/nagios.cfg; then
    echo -e "\ncfg_dir=/opt/monitor/etc/synergy\n" >> /opt/monitor/etc/nagios.cfg
else
    touch /opt/monitor/etc/nagios.cfg
fi

if [ "$1" -eq 1 ]
then
	echo "Verifying names..."
	if php /opt/monitor/op5/nacoma/api/monitor.php -t service_template -a list_objects -u monitor 2>&1 | grep -i duplicate | grep -q 'bizproc_service' ||
		php /opt/monitor/op5/nacoma/api/monitor.php -t command -a list_objects -u monitor 2>&1 | grep -i duplicate | grep -q 'bizproc_pas'
	then
		mkdir -p /opt/synergy/etc/monitor
		mv /opt/monitor/etc/synergy/* /opt/synergy/etc/monitor/
		echo "
************************************
Name clash detected.
For correct work of op5 business services it needs to install
service template bizproc_service and check command bizproc_pas.
Seems that you already have the objects with these names,
so we skipped this step to keep the config sane.
Please, rename your monitor objects, then manually move files for business services to work properly:
  mv /opt/synergy/etc/monitor/* /opt/monitor/etc/synergy
************************************"
	fi
fi

service monitor reload || true
if [ "$1" -eq 1 ]
then
    chkconfig --add synergy
else
    pkill -f '/opt/synergy/bin/synergy --monitor'
fi
service synergy start
true

%preun
if [ "$1" -eq 0 ]
then
    /opt/synergy/etc/init.d/processor stop
    true
fi

%files
%defattr(664,%daemon_user,%daemon_group,775)
/opt/monitor/op5/ninja/modules/synergy/
%prefix/etc
%prefix/var
%prefix/sql
%config(noreplace) /opt/monitor/etc/synergy/command.cfg
%config(noreplace) /opt/monitor/etc/synergy/services.cfg
%dir %prefix/var/run
/etc/op5kad/conf.d/synergy.kad
%attr(755,root,root) %prefix/scripts/*
%attr(755,root,root) %prefix/bin/*
%attr(755,root,root) %prefix/share/*
%attr(755,root,root) %prefix/etc/config.lua
%attr(755,root,root) /opt/monitor/op5/nacoma/hooks/save/synergy_hook.py
%attr(644,root,root) /opt/monitor/op5/nacoma/hooks/save/synergy_hook.pyc
%attr(644,root,root) /opt/monitor/op5/nacoma/hooks/save/synergy_hook.pyo
%attr(664,%apache_group,%daemon_group) /opt/synergy/etc/bps/Test-Drive.lua
%attr(755,root,root) /etc/init.d/synergy
%attr(644,root,root) /etc/op5-backup/modules/external/op5-synergy

%exclude %prefix/test
%exclude %prefix/features
%exclude %prefix/Makefile

%files test
%defattr(644,%daemon_user,%daemon_group,755)
%prefix/test
%prefix/features
%attr(755,root,root) %prefix/test/lunit/lunit
%prefix/Makefile

%clean
rm -rf %buildroot
